Overview
--------

Ralph is the complete *Asset Management*, *DCIM* and *CMDB* system for large Data Centers
as well as smaller LAN networks.

Ralph consists of 3 dedicated subsystems:

Ralph Core
**********
(DCIM and CMDB) - allows you to discover/scan hardware automatically.
Ralph Core can control configuration of IPAddresses, Networks, Racks.
You can also generate DHCP and DNS entries for your hosts. It is compatible with CMDB
specification and has Zabbix, Jira and Puppet integration.

Ralph Assets
************
Asset management system which keep track of purchases
of your hardware, and hardware ownership with workflow and PDF documents outprints
for your customers.

Ralph Pricing
*************
Flexible billing and financial reporting subsystem which can
show you how much your business services costs. We provide OpenStack integration
for billings.


